@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 1;
 
@@ -19,9 +19,16 @@ __END__
 
 Task::Map::Tube - Install the Map::Tube modules.
 
+=head1 SYNOPSIS
+
+ cpanm Task::Map::Tube
+
 =head1 SEE ALSO
 
+L<Task::MapMetro::Maps>.
+
 L<Map::Tube>,
+L<Map::Tube::Graph>,
 L<Map::Tube::GraphViz>,
 L<Map::Tube::Text::Table>,
 
@@ -68,6 +75,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
